import pytest
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from database_models.models import Base, YourModel  # Import your models

# Setup test database
TEST_DATABASE_URL = "sqlite:///./test.db"
engine = create_engine(TEST_DATABASE_URL)
TestingSessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

@pytest.fixture(scope="function")
def db_session():
    Base.metadata.create_all(bind=engine)
    session = TestingSessionLocal()
    try:
        yield session
    finally:
        session.close()
        Base.metadata.drop_all(bind=engine)

def test_create_model(db_session):
    model = YourModel(name="Test Name", description="Test Description")
    db_session.add(model)
    db_session.commit()
    
    assert db_session.query(YourModel).filter_by(name="Test Name").first() is not None

# Add more tests as needed